This crate contains kube-rs compatible bindings for Kubernetes custom resources for the s3.snappcloud.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
s3.snappcloud.io/v1alpha1
S3BucketS3UserClaimS3User